@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # Copyright (C) 2005, 2006, 2007 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
@@ -15,17 +14,15 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from __future__ import absolute_import
-
+import difflib
 import os
 import sys
 import time
-import difflib
-
+from typing import Type
 
 __all__ = ['PatienceSequenceMatcher', 'unified_diff', 'unified_diff_files']
 
-__version__ = (0, 2, 0)
+__version__ = (0, 2, 13)
 
 
 # This is a version of unified_diff which only adds a factory parameter
@@ -129,45 +126,17 @@ def unified_diff_files(a, b, sequencematcher=None):
                         sequencematcher=sequencematcher)
 
 
+PatienceSequenceMatcher: Type[difflib.SequenceMatcher]
+
+
 try:
-    from ._patiencediff_c import (
-        unique_lcs_c as unique_lcs,
-        recurse_matches_c as recurse_matches,
+    from ._patiencediff_c import \
         PatienceSequenceMatcher_c as PatienceSequenceMatcher
-        )
+    from ._patiencediff_c import recurse_matches_c as recurse_matches
+    from ._patiencediff_c import unique_lcs_c as unique_lcs
 except ImportError:
-    from ._patiencediff_py import (  # noqa: F401
-        unique_lcs_py as unique_lcs,
-        recurse_matches_py as recurse_matches,
-        PatienceSequenceMatcher_py as PatienceSequenceMatcher
-        )
-
-
-def main(args):
-    import optparse
-    p = optparse.OptionParser(usage='%prog [options] file_a file_b'
-                                    '\nFiles can be "-" to read from stdin')
-    p.add_option('--patience', dest='matcher', action='store_const',
-                 const='patience', default='patience',
-                 help='Use the patience difference algorithm')
-    p.add_option('--difflib', dest='matcher', action='store_const',
-                 const='difflib',
-                 default='patience', help='Use python\'s difflib algorithm')
-
-    algorithms = {
-        'patience': PatienceSequenceMatcher,
-        'difflib': difflib.SequenceMatcher}
-
-    (opts, args) = p.parse_args(args)
-    matcher = algorithms[opts.matcher]
-
-    if len(args) != 2:
-        print('You must supply 2 filenames to diff')
-        return -1
-
-    for line in unified_diff_files(args[0], args[1], sequencematcher=matcher):
-        sys.stdout.write(line)
-
-
-if __name__ == '__main__':
-    sys.exit(main(sys.argv[1:]))
+    from ._patiencediff_py import \
+        PatienceSequenceMatcher_py as PatienceSequenceMatcher  # noqa: F401
+    from ._patiencediff_py import \
+        recurse_matches_py as recurse_matches  # noqa: F401
+    from ._patiencediff_py import unique_lcs_py as unique_lcs  # noqa: F401
